#include "qimagelabel.h"

#include <QBuffer>
#include <QMimeData>
#include <QDebug>

QImageLabel::QImageLabel(QWidget* parent) : QLabel(parent)
{
    setAcceptDrops(true);
}

QImageLabel::~QImageLabel()
{

}

bool QImageLabel::hasImage() const
{
    return !droppedImage.isNull();
}

void QImageLabel::setImage(const QByteArray& data, const char* fmt)
{
    if(data.isEmpty())
    {
        droppedImage = QImage();
        QLabel::setPixmap(QPixmap());
    }
    else
    {
        QPixmap pix;
        pix.loadFromData(data,fmt);
        droppedImage = pix.toImage();
        QLabel::setPixmap(pix.scaled(this->size(),Qt::KeepAspectRatio, Qt::SmoothTransformation));
    }
}

QByteArray QImageLabel::getImage(const char* fmt) const
{
    if(droppedImage.isNull())
    {
        return QByteArray();
    }

    QBuffer buf;
    buf.open(QIODevice::ReadWrite);
    droppedImage.save(&buf,fmt);
    buf.close();
    return buf.data();
}

bool QImageLabel::readOnly() const
{
    return !acceptDrops();
}

void QImageLabel::setReadOnly(bool on)
{
    setAcceptDrops(!on);
    qDebug()<<"qimagelabel: accepting drops - "<<acceptDrops();
}

void QImageLabel::dragEnterEvent(QDragEnterEvent *event)
{
    if(event->mimeData()->hasImage() || event->mimeData()->hasUrls())
    {
        event->acceptProposedAction();
    }
    else
    {
        qDebug()<<"No IMAGE in drop object - discard";
    }
}

void QImageLabel::dropEvent(QDropEvent* event)
{
    if(event->mimeData()->hasImage())
    {
        droppedImage = qvariant_cast<QImage>(event->mimeData()->imageData());
    }
    else if(event->mimeData()->hasUrls())
    {
        bool ok = false;
        foreach(QUrl url, event->mimeData()->urls())
        {
            QImage img(url.path());
            if(!img.isNull())
            {
                droppedImage = img;
                ok = true;
                break;
            }
        }
        if(!ok) return;
    }
    else
    {
        return;
    }

    QLabel::setPixmap(QPixmap::fromImage(droppedImage).scaled(this->size(), Qt::KeepAspectRatio, Qt::SmoothTransformation));
    event->acceptProposedAction();
}
